@@ -42,7 +42,7 @@ use Params::Validate qw{:all};
 use Try::Tiny;
 
 # we get 'spawn', 'reset', and accessors from parent
-use parent 'App::Dochazka::Model::Activity';
+use parent 'App::Dochazka::Common::Model::Activity';
 
 
 
@@ -54,17 +54,6 @@ App::Dochazka::REST::Model::Activity - activity data model
 
 
 
-=head1 VERSION
-
-Version 0.466
-
-=cut
-
-our $VERSION = '0.466';
-
-
-
-
 =head1 SYNOPSIS
 
     use App::Dochazka::REST::Model::Activity;
