@@ -41,7 +41,7 @@ use App::Dochazka::REST::Model::Shared qw( canonicalize_tsrange cud load load_mu
 use Params::Validate qw( :all );
 
 # we get 'spawn', 'reset', and accessors from parent
-use parent 'App::Dochazka::Model::Interval';
+use parent 'App::Dochazka::Common::Model::Interval';
 
 
 
@@ -52,17 +52,6 @@ App::Dochazka::REST::Model::Interval - activity intervals data model
 
 
 
-=head1 VERSION
-
-Version 0.466
-
-=cut
-
-our $VERSION = '0.466';
-
-
-
-
 =head1 SYNOPSIS
 
     use App::Dochazka::REST::Model::Interval;
