@@ -42,7 +42,7 @@ use Params::Validate qw( :all );
 use Try::Tiny;
 
 # we get 'spawn', 'reset', and accessors from parent
-use parent 'App::Dochazka::Model::Privhistory';
+use parent 'App::Dochazka::Common::Model::Privhistory';
 
 
 
@@ -54,17 +54,6 @@ App::Dochazka::REST::Model::Privhistory - privilege history functions
 
 
 
-=head1 VERSION
-
-Version 0.466
-
-=cut
-
-our $VERSION = '0.466';
-
-
-
-
 =head1 SYNOPSIS
 
     use App::Dochazka::REST::Model::Privhistory;
