@@ -41,7 +41,7 @@ use Data::Dumper;
 use Params::Validate qw( :all );
 
 # we get 'spawn', 'reset', and accessors from parent
-use parent 'App::Dochazka::Model::Schedhistory';
+use parent 'App::Dochazka::Common::Model::Schedhistory';
 
 
 
@@ -53,17 +53,6 @@ App::Dochazka::REST::Model::Schedhistory - schedule history functions
 
 
 
-=head1 VERSION
-
-Version 0.466
-
-=cut
-
-our $VERSION = '0.466';
-
-
-
-
 =head1 SYNOPSIS
 
     use App::Dochazka::REST::Model::Schedhistory;
