@@ -44,7 +44,7 @@ use Params::Validate qw( :all );
 use Try::Tiny;
 
 # we get 'spawn', 'reset', and accessors from parent
-use parent 'App::Dochazka::Model::Schedintvls';
+use parent 'App::Dochazka::Common::Model::Schedintvls';
 
 
 
@@ -56,17 +56,6 @@ App::Dochazka::REST::Model::Schedintvls - object class for "scratch schedules"
 
 
 
-=head1 VERSION
-
-Version 0.466
-
-=cut
-
-our $VERSION = '0.466';
-
-
-
-
 =head1 SYNOPSIS
 
     use App::Dochazka::REST::Model::Schedintvls;
@@ -76,21 +65,6 @@ our $VERSION = '0.466';
 
 
 
-#=head1 EXPORTS
-#
-#This module provides the following exports:
-#
-#=over 
-#
-#=back
-#
-#=cut
-#
-#use Exporter qw( import );
-#our @EXPORT_OK = qw( );
-
-
-
 =head1 METHODS
 
 
