@@ -43,7 +43,7 @@ use Params::Validate qw( :all );
 use Try::Tiny;
 
 # we get 'spawn', 'reset', and accessors from parent
-use parent 'App::Dochazka::Model::Schedule';
+use parent 'App::Dochazka::Common::Model::Schedule';
 
 
 
@@ -55,17 +55,6 @@ App::Dochazka::REST::Model::Schedule - schedule functions
 
 
 
-=head1 VERSION
-
-Version 0.466
-
-=cut
-
-our $VERSION = '0.466';
-
-
-
-
 =head1 SYNOPSIS
 
     use App::Dochazka::REST::Model::Schedule;
