@@ -55,6 +55,7 @@ use Data::Dumper;
 use Params::Validate qw( :all );
 use Try::Tiny;
 
+my $fail = $CELL->status_not_ok;
 
 
 =head1 NAME
@@ -64,27 +65,11 @@ App::Dochazka::REST::Dispatch::Shared - Shared dispatch functions
 
 
 
-
-=head1 VERSION
-
-Version 0.466
-
-=cut
-
-our $VERSION = '0.466';
-
-my $fail = $CELL->status_not_ok;
-
-
-
-
 =head1 DESCRIPTION
 
 This module provides code that is, or may be, used by more than one resource
 handler method.
 
-=cut
-
 
 
 
@@ -346,7 +331,7 @@ sub shared_insert_employee {
     hash_the_password( $new_emp_props );
 
     # spawn an object, filtering the properties first
-    my @filtered_args = App::Dochazka::Model::Employee::filter( %$new_emp_props );
+    my @filtered_args = App::Dochazka::Common::Model::Employee::filter( %$new_emp_props );
     my %proplist_after = @filtered_args;
     $log->debug( "Properties after filter: " . join( ' ', keys %proplist_after ) );
     my $emp = App::Dochazka::REST::Model::Employee->spawn( @filtered_args );
@@ -710,7 +695,7 @@ sub shared_insert_activity {
     $log->debug( "Properties before filter: " . join( ' ', keys %proplist_before ) );
         
     # spawn an object, filtering the properties first
-    my @filtered_args = App::Dochazka::Model::Activity::filter( %proplist_before );
+    my @filtered_args = App::Dochazka::Common::Model::Activity::filter( %proplist_before );
     my %proplist_after = @filtered_args;
     $log->debug( "Properties after filter: " . join( ' ', keys %proplist_after ) );
     my $act = App::Dochazka::REST::Model::Activity->spawn( @filtered_args );
@@ -763,8 +748,8 @@ sub shared_insert_intlock {
 
     # dispatch
     my %dispatch = (
-        'Interval' => \&App::Dochazka::Model::Interval::filter,
-        'Lock' => \&App::Dochazka::Model::Lock::filter,
+        'Interval' => \&App::Dochazka::Common::Model::Interval::filter,
+        'Lock' => \&App::Dochazka::Common::Model::Lock::filter,
     );
 
     # spawn an object, filtering the properties first
