@@ -40,7 +40,7 @@ use strict;
 use warnings;
 
 use App::CELL qw( $CELL $meta $site );
-use App::Dochazka;
+use App::Dochazka::Common;
 use App::Dochazka::REST::ConnBank qw( $dbix_conn conn_status );
 use App::Dochazka::REST::Util qw( hash_the_password );
 use App::Dochazka::REST::Model::Privhistory qw( get_privhistory );
@@ -66,18 +66,6 @@ App::Dochazka::REST::Test - Test helper functions
 
 
 
-=head1 VERSION
-
-Version 0.466
-
-=cut
-
-our $VERSION = '0.466';
-
-
-
-
-
 =head1 DESCRIPTION
 
 This module provides helper code for unit tests.
